#
# spec file for package libvpl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
  %define _distconfdir %{_prefix}%{_sysconfdir}
%endif

%global sover 2
Name:           libvpl
%define lname   libvpl%{sover}
Version:        2.13.0
Release:        1.1
Summary:        oneAPI Video Processing Library (oneVPL) dispatcher, tools, and examples
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/oneapi-src/oneVPL
Source0:        https://github.com/oneapi-src/oneVPL/archive/refs/tags/v%{version}.tar.gz#/libvpl-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(wayland-client)
%if 0%{?suse_version} > 1600
ExclusiveArch:  x86_64 %ix86 aarch64
%else
ExclusiveArch:  x86_64 aarch64
%endif

%description
The oneAPI Video Processing Library (oneVPL) provides a single video processing
API for encode, decode, and video processing that works across a wide range of
accelerators.

%package -n %lname
Summary:        oneAPI Video Processing Library (oneVPL) dispatcher
Group:          System/Libraries

%description -n %lname
The oneAPI Video Processing Library (oneVPL) provides a single video processing
API for encode, decode, and video processing that works across a wide range of
accelerators.

%package devel
Summary:        Development files for oneAPI Video Processing Library (oneVPL) dispatcher
Group:          Development/Languages/C and C++
Requires:       %lname = %version

%description devel
This package contains the development headers and pkgconfig files for
the oneAPI Video Processing Library (oneVPL) dispatcher

%prep
%autosetup -p1 -n libvpl-%{version}

%build
%cmake \
  %{nil}
%cmake_build

%install
%cmake_install

%ldconfig_scriptlets -n %lname

%files
%doc README.md third-party-programs.txt

%files -n %lname
%license LICENSE
%dir %{_distconfdir}
#%dir %{_distconfdir}/modulefiles
%dir %{_distconfdir}/vpl
#%{_distconfdir}/modulefiles/vpl
%{_distconfdir}/vpl/vars.sh
%{_libdir}/libvpl.so.%{sover}
%{_libdir}/libvpl.so.%{sover}.*

%files devel
%doc
%{_includedir}/vpl/
%{_libdir}/libvpl.so
%{_libdir}/pkgconfig/vpl.pc
%{_libdir}/cmake/vpl/
%{_datadir}/vpl/

%changelog
* Wed Sep  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.13.0:
  + Added:
  - Intel® VPL API 2.13 support, including new APIs for AV1
    screen content tools, encoded picture quality information,
    alpha channel encoding, AI-based frame interpolation,
    AI-based super resolution, and Battlemage platform
  - hello-encode-jpeg example
- Changes from version 2.12.0:
  + Added: Intel® VPL API 2.12 support, including new APIs for
    AI-based frame interpolation and Vulkan zero-copy surface
    sharing.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.11.0
  + Added: Intel® VPL API 2.11 support
  + Removed: Command line tools. They have been moved to a separate
    repository (https://github.com/intel/libvpl-tools)
- Drop samples sub-package as the tools have been removed upstream
- Drop u_buildfix-i586.patch, no longer needed nor applies after
  removal of tools
- Use ldconfig_scriptlets macro for post(un) handling.
* Mon Feb  5 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable build on aarch64
* Sat Jan 20 2024 Stefan Dirsch <sndirsch@suse.com>
- u_buildfix-i586.patch
  * fixed build on i586
* Fri Jan 19 2024 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.10.1
  + Changed
  * Project name to Intel® Video Processing Library (Intel® VPL)
  * Project versioning scheme to align with library and API
    version
  + Added
  * Intel® VPL specification and associated build scripts
  + Known Issues
  * sample_decode may report "DeliverOutput return error = -1"
    when run using -r option
  * vpl-infer example will fail to load model if built with CMake
    version higher than 3.25.3 on Windows
- Add libva build dep
* Mon Dec  4 2023 Stefan Dirsch <sndirsch@suse.com>
- This includes latest version of one of the components needed for
  Video (processing) hardware support on Intel GPUs (bsc#1217770)
* Mon Dec  4 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2023.4.0
  * Added
    + oneVPL API 2.10 support
    + New command line parameters to sample_multi_transcode for setting
    B Frame QP Offsets based on Pyramid Level
    + New command line parameters to the sample_vpp tool to enable video
    signal information
    + New APIs for importing and exporting shared surfaces
    + New APIs for string-based parameter configuration
  * Removed
    + Environment module support
    + Unused files and folders
  * Fixed
    + NV12 wayland render for MTL
    + Buffer starvation when wayland window is moved
    + Missing profile strings in vpl-inspect tool
    + Rdrm to use card node instead of render node
    + Rdrm tile4 selection based DRM/KMS query
    + Rdrm NV12 and P010 render for MTL
  * Changed
    + Directory layout and name of dispatcher directory
    + Location of image files used by documentation
    + Runtime library search path to remove current directory
* Wed Nov 29 2023 Stefan Dirsch <sndirsch@suse.com>
- only build %%ix86 for Tumbleweed; otherwise just build it for
  x86_64 (bsc#1217662)
* Mon Apr 10 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2023.2.0
  * Added
    + oneVPL API 2.9 support
    + Perceptual encoding prefilter option to
    sample_multi_transcode
  * Fixed
    + VPP processing for YUV input
    + Sample_multi_transcode segfault on wayland
    + Missing prerequisites in vpl-infer README
  * Changed
    + vpl-infer Dockerfile and Linux setup steps to better align
    with https://dgpu-docs.intel.com/
  * Removed
    + dpcpp-blur example
- Drop upstreamed fix_arm_ilp32.patch
* Tue Jan 17 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2023.1.1
  * Added
    + Help screen listing valid options for vpl-inspect
    + YUV400 option for JPEG encoding with sample_encode
    + Build option --disable_experimental to build with
    ONEVPL_EXPERIMENTAL disabled
  * Changed
    + Session creation example to request a minimum API version
- Update to version 2023.1.0
  * Added
    + oneVPL API 2.8 support
    + New infer sample
    + xdg_shell for weston10
  * Fixed
    + NOT_ENOUGH_BUFFER error when HRD off in ExtBRC
    + Legacy tools using x86/x86_64 specific assembler code
    + Pkg-config files not installing in correct location in cross
    compilation scenarios
- Reenable other architectures again for all products.
  * Add fix_arm_ilp32.patch
- Drop upstream remove_x86_64_check.patch
* Tue Nov 15 2022 Stefan Dirsch <sndirsch@suse.com>
- missed part of specfile to limit build to x86_64 on older
  products than factory
* Tue Nov  8 2022 Stefan Dirsch <sndirsch@suse.com>
- limit build again to x86_64 on older products than factory
* Mon Nov  7 2022 Stefan Dirsch <sndirsch@suse.com>
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Wed Nov  2 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2023.0.0
  * new bump from master branch
* Sat Sep 24 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2022.2.4
  * Add SMPTE ST 2084A color description preset
  * Add parallel encoding support
  * Add dynamic bitstream buffer reallocation
* Mon Sep 19 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2022.2.3
  * Multiple hardware adapters are supported as part of the 2.6
    API update. They provide faster performance by taking advantage
    of available platform resources.
  * MPEG2 decode is now supported in a CPU implementation to
    improve codec coverage for systems that do not have dedicated
    hardware.
* Mon Sep 19 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Enable build on all archs, oneVPL is platform agnostic, add
  remove_x86_64_check.patch
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2022.1.5
  * oneVPL 2022.1.0 has been updated to include functional and
    security updates.
  * part of oneVPL GPU Runtime 2022Q2 Release - 22.4.4
- third-party-programs.txt issue has been fixed; license.txt removed
  as well
- examples moved to /usr/share/vpl
- packaged new config scripts /usr/etc/modulefiles/vpl and
  /usr/etc/vpl/vars.sh
* Tue Nov  2 2021 Stefan Dirsch <sndirsch@suse.com>
- remove third-party-programs.txt during setup
  * When not building on Windows using Visual Studio, the Visual
    Studio runtimes are not needed to be installed so we can remove
    these licenses from being mentioned. On Linux we're using
    cmake/make/gcc for building/installation and we don't have any
    (need for) MS Visual Studio runtime. (oneapi-src/oneVPL issue#27)
  - -> https://github.com/oneapi-src/oneVPL/issues/27
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed JIRA number in previous changelog
* Thu Sep 23 2021 Stefan Dirsch <sndirsch@suse.com>
- created package libvpl (jira#SLE/SLE-19361)
  * oneAPI Video Processing Library (oneVPL) dispatcher, tools, and
    examples: The oneAPI Video Processing Library (oneVPL) provides
    a single video processing API for encode, decode, and video
    processing that works across a wide range of accelerators.
